@@ -127,6 +127,7 @@ Board::Board(MainWindow& win) :
 	,m_usebook(true)
 	,m_human_black(false)
 	,theme("wood")
+	,color("#198964")
 {
 
 	std::list<Gtk::TargetEntry> listTargets;
@@ -161,6 +162,10 @@ Board::~Board()
 	m_robot.stop();
 }
 
+void Board::set_trace_color(const std::string& color_)
+{
+	color = color_;
+}
 void Board::set_themes(const std::string& themes_)
 {
 	theme = themes_;
@@ -170,17 +175,19 @@ void Board::set_themes(const std::string& themes_)
 }
 Glib::RefPtr<Gdk::Pixbuf> Board::get_pic(const std::string& name_)
 {
-	char path[1024];
-	sprintf(path, DATA_DIR"/themes/%s/%s",theme.c_str(),name_.c_str());
-	return Gdk::Pixbuf::create_from_file(path);
+    const std::string path = \
+            std::string(DATA_DIR) + \
+            "/themes/" + theme + "/" + name_;
+    return Gdk::Pixbuf::create_from_file(path);
 
 }
 
 Glib::RefPtr<Gdk::Pixbuf> Board::get_spic(const std::string& name_)
 {
-	char path[1024];
-	sprintf(path, DATA_DIR"/themes/%s-small/%s",theme.c_str(),name_.c_str());
-	return Gdk::Pixbuf::create_from_file(path);
+    const std::string path = \
+            std::string(DATA_DIR) + \
+            "/themes/" + theme + "-small/" + name_;
+    return Gdk::Pixbuf::create_from_file(path);
 
 }
 
@@ -205,7 +212,7 @@ void Board::load_images()
 		chessman_images[RED_PAWN] = get_spic("red_pawn.png");
 		chessman_images[RED_ROOK] = get_spic("red_rook.png");
 		chessman_images[SELECTED_CHESSMAN] = get_spic("select.png");
-		chessman_images[NULL_CHESSMAN] = get_spic("null.png");
+		chessman_images[PROPMT] = get_spic("null.png");
 	}
 	else{
 
@@ -226,7 +233,7 @@ void Board::load_images()
 		chessman_images[RED_PAWN] = get_pic("red_pawn.png");
 		chessman_images[RED_ROOK] = get_pic("red_rook.png");
 		chessman_images[SELECTED_CHESSMAN] = get_pic("select.png");
-		chessman_images[NULL_CHESSMAN] = get_pic("null.png");
+		chessman_images[PROPMT] = get_pic("null.png");
 	}
 }
 
@@ -321,6 +328,21 @@ void Board::redraw()
 			x,y);
 }
 
+void Board::redraw_with_line(int mv,bool select)
+{
+	draw_bg();
+	draw_trace(mv);
+	draw_board();
+	int x,y;
+	ui_pixmap->get_size(x,y);
+	this->get_window()->draw_drawable(this->get_style()->get_black_gc(),ui_pixmap,
+			0,0,
+			0,0,
+			x,y);
+	draw_select_frame(select);
+	
+}
+
 /**处理点击事件, handle the click events*/
 bool Board::on_button_press_event(GdkEventButton* ev)
 {
@@ -334,7 +356,6 @@ bool Board::on_button_press_event(GdkEventButton* ev)
 	if(ev->type == GDK_BUTTON_PRESS&& ev->button == 1)
 	{
 		redraw();
-		//draw_select_frame(false);
 		Gdk::Point p = get_position(ev->x, ev->y);
 		selected_x = p.get_x();
 		selected_y = p.get_y();
@@ -357,12 +378,12 @@ bool Board::on_button_press_event(GdkEventButton* ev)
 					if((m_human_black && (selected_chessman <32))||((!m_human_black)&&(selected_chessman>31))){
 						printf("choose black %d\n",selected_chessman);
 						selected_chessman =-1;
-						//draw_select_frame(false); 
 						return true;
 					}
 				}
 
 				draw_select_frame(true);
+				draw_show_can_move();
 			}
 		}
 		else{
@@ -374,16 +395,16 @@ bool Board::on_button_press_event(GdkEventButton* ev)
 				/** change the select */
 				selected_chessman = dst_chessman;
 				draw_select_frame(true);
+				draw_show_can_move();
 				CSound::play(SND_CHOOSE);
 
 			}
-			else if(dst_chessman == 0){
+		//else if(dst_chessman == 0){
+		else{
 				/** 目标地点没有棋子可以直接生成着法，当然还需要检测一下从源地点到终点是否是合法的着法，交由下面着法生成函数负责*/
-				try_move(selected_x,selected_y);
-			}
-			else{
 				/** 目标地点有对方棋子，其实也可以给着法生成函数搞啊*/
 				try_move(selected_x,selected_y);
+				
 			}
 
 
@@ -565,6 +586,47 @@ void Board::draw_chessman(int x, int y, int chessman)
 			Gdk::RGB_DITHER_NONE, 0, 0);
 }
 
+void Board::draw_show_can_move()
+{
+	if(!is_fight_to_robot()&& !is_network_game())
+		return;
+
+	if (selected_chessman < 0 )
+		return;
+	std::vector<Gdk::Point> points;
+	m_engine.gen_which_can_move(points, selected_chessman, is_rev_board);
+
+	std::vector<Gdk::Point>::iterator iter = points.begin();
+
+	for(;iter != points.end(); ++iter){
+		Gdk::Point p = get_coordinate(iter->get_x(), iter->get_y());
+		draw_phonily_point(p);
+	}
+
+}
+
+void Board::draw_phonily_point(Gdk::Point& p)
+{
+	int px = p.get_x() - 11 / 2;
+	int py = p.get_y() - 11 / 2;
+	//int px = p.get_x() - chessman_width / 2;
+	//int py = p.get_y() - chessman_width / 2;
+	//ui_pixmap->copy_to_image(selected_chessman_image, px, py, 0, 0, chessman_width, chessman_width);
+	//ui_pixmap->draw_pixbuf(get_style()->get_black_gc(),chessman_images[SELECTED_CHESSMAN],
+	//			0, 0, px, py, chessman_images[SELECTED_CHESSMAN]->get_width(), chessman_images[SELECTED_CHESSMAN]->get_height(), 
+	//			Gdk::RGB_DITHER_NONE, 0, 0);
+	ui_pixmap->copy_to_image(selected_chessman_image, px, py, 0, 0, 11, 11);
+	ui_pixmap->draw_pixbuf(get_style()->get_black_gc(),chessman_images[PROPMT],
+				0, 0, px, py, chessman_images[PROPMT]->get_width(), chessman_images[PROPMT]->get_height(), 
+				Gdk::RGB_DITHER_NONE, 0, 0);
+	int x,y;
+	ui_pixmap->get_size(x,y);
+	this->get_window()->draw_drawable(this->get_style()->get_black_gc(),ui_pixmap,
+			0,0,
+			0,0,
+			x,y);
+}
+
 void Board::draw_select_frame(bool selected)
 {
 	if (selected_chessman < 0 || selected_x == -1 || selected_y == -1)
@@ -600,21 +662,6 @@ void Board::draw_select_frame(bool selected)
 
 }
 
-void Board::draw_pieces()
-{
-#if 0
-	int i,j;
-	i = PIECE_START;
-	for(;i<PIECE_END;i++)
-	{
-		int sq = pieces[i];
-		if(sq == 0||sq<0x33||sq>0xcb)
-			continue;
-		draw_chessman(RANK_X(sq),RANK_Y(sq),get_chessman_type(i));
-	}
-	draw_select_frame(true);
-#endif
-}
 
 void Board::draw_board()
 {
@@ -625,6 +672,23 @@ void Board::draw_board()
 	}
 }
 
+void Board::draw_trace(int mv)
+{
+	int src = m_engine.get_move_src(mv);
+	int dst = m_engine.get_move_dst(mv);
+
+	Glib::RefPtr<Gdk::GC> gc = this->get_style()->get_white_gc();
+	gc->set_rgb_fg_color(Gdk::Color(color));
+	Gdk::Point s1 =get_coordinate(m_engine.RANK_X(src)-3,m_engine.RANK_Y(src)-3);
+	Gdk::Point s2 =get_coordinate(m_engine.RANK_X(dst)-3,m_engine.RANK_Y(dst)-3);
+
+	gc->set_line_attributes(4,Gdk::LINE_SOLID, Gdk::CAP_NOT_LAST, Gdk::JOIN_BEVEL);
+	std::vector<Gdk::Point> poss;
+	poss.push_back(s1);
+	poss.push_back(s2);
+	ui_pixmap->draw_lines(gc, poss);
+
+}
 void Board::first_move()
 {
 	m_step = 0;
@@ -732,8 +796,6 @@ int Board::try_move(int dst_x,int dst_y)
 	int dst = m_engine.get_dst_xy(dst_x,dst_y,is_rev_board);
 	int src = m_engine.get_chessman_xy(selected_chessman);
 	int mv =  m_engine.get_move(src,dst);
-	int eat = m_engine.get_move_eat(mv);
-	DLOG("Board:: src = %x dst = %x mv = %d eat = %d\n",src,dst,mv,eat);
 	return try_move(mv);
 }
 int Board::try_move(int mv)
@@ -755,10 +817,9 @@ int Board::try_move(int mv)
 		else
 			CSound::play(SND_MOVE);
 
-		redraw();
+		redraw_with_line(mv,true);
 		selected_chessman = m_engine.get_piece(dst);
-		draw_select_frame(true);
-		printf("sleceted = %d finish move and redraw now\n",selected_chessman);
+		printf("move = %d finish move and redraw now\n",mv);
 		selected_chessman=-1;
 
 		std::string iccs_str=m_engine.move_to_iccs_str(mv);
@@ -809,6 +870,7 @@ int Board::try_move(int mv)
 			count_time=0;
 
 		}
+		parent.set_comment("");
 
 		/**被将死了*/
 		/** is it  mate */
@@ -817,12 +879,17 @@ int Board::try_move(int mv)
 				timer.disconnect();
 			CSound::play(SND_CHECK);
 			parent.on_end_game(ROBOT_WIN);
+			parent.set_comment("不要气馁，再接再大励吧!");
 			DLOG("将军死棋\n");
 			return 0;
 		}
 		if(m_engine.get_checkby()){
 			CSound::play(SND_CHECK);
 			DLOG("将军===============\n");
+			if(is_human_player())
+				parent.set_comment("您被将军了，小心噢!");
+			else
+				parent.set_comment("将军，干得好，看好你噢!");
 		}
 
 	}
@@ -924,13 +991,17 @@ void Board::rev_game()
 	redraw();
 }
 
-void Board::start_robot()
+void Board::start_robot(bool new_)
 {
 	m_status = FIGHT_STATUS;
 
+	m_robot.set_engine(engine_name);
 	m_robot.start();
 	m_robot.send_ctrl_command("ucci\n");
-	new_game(m_status);
+	if(new_)
+		new_game(m_status);
+	else
+		chanju_game(m_status);
 }
 
 void Board::set_level_config(int _depth,int _idle,int _style,int _knowledge,int _pruning,int _randomness,bool _usebook)
@@ -976,6 +1047,50 @@ void Board::start_network()
 
 }
 
+void Board::chanju_game(BOARD_STATUS _status)
+{
+	m_status = _status;
+	std::string cur_fen = m_engine.get_current_snapshot();
+	m_engine.init_snapshot(cur_fen.c_str());
+
+	if(m_status == FIGHT_STATUS){
+		set_war_time(step_time,play_time);
+		m_robot.send_ctrl_command("setoption newgame\n");
+		set_level();
+	}
+	DLOG("current fen = %s\n", cur_fen.c_str());
+
+
+	moves_lines.clear();
+	moves_lines = postion_str + cur_fen;
+	redraw();
+
+	parent.textview_engine_log_clear();
+	parent.change_play(is_human_player());
+
+	timer=Glib::signal_timeout().connect(sigc::mem_fun(*this,&Board::go_time),1000);
+	/**如果是用户选择黑方，则电脑先走棋 -- if user choose black,the robot go moves first*/
+	if(m_human_black){
+		if(m_status == FIGHT_STATUS){
+			moves_lines =moves_lines +std::string(" -- 0 1 ");
+			m_robot.send_ctrl_command(moves_lines.c_str());
+			m_robot.send_ctrl_command("\n");
+			char str_cmd[256];
+			sprintf(str_cmd,"go depth %d \n",m_search_depth);
+			m_robot.send_ctrl_command(str_cmd);
+		}else if(m_status == NETWORK_STATUS){
+
+		}
+
+	}
+
+	parent.set_red_war_time(to_time_ustring(red_time),to_time_ustring(0));
+	parent.set_black_war_time(to_time_ustring(black_time),to_time_ustring(0));
+
+
+}
+
+
 void Board::new_game(BOARD_STATUS _status)
 {
 	m_status = _status;
@@ -1020,7 +1135,7 @@ void Board::new_game(BOARD_STATUS _status)
 bool Board::robot_log(const Glib::IOCondition& condition)
 {
 	/*for testing,delete me*/
-	char buf[1024];
+	char buf[1024] = {0};
 	int buf_len = 1024;
 	char* p = buf;
 	for (; buf_len > 0; ) {
@@ -1033,7 +1148,7 @@ bool Board::robot_log(const Glib::IOCondition& condition)
 
 	if (buf_len > 0) {
 		*p = 0;
-		printf(buf);
+		printf("%s", buf);
 		std::string str_buf(buf);
 		parent.show_textview_engine_log(str_buf);
 
@@ -1207,7 +1322,7 @@ bool Board::on_network_io(const Glib::IOCondition& )
 
 	int fd_cli = -1;
        EC_THROW(-1 == (fd_cli = accept(fd_recv_skt, NULL, 0)));
-       char buf[1024];
+       char buf[1024] = {0};
        size_t len = read(fd_cli, &buf[0], 1023);
        buf[len]=0;
        if (len > 0) {
@@ -1274,72 +1389,6 @@ bool Board::on_network_io(const Glib::IOCondition& )
 		}
 
 
-
-
-
-#if 0
-		if(pos_ != std::string::npos){
-			//start network game with red player
-			parent.on_network_game("lerosua","enemy",true);
-		}
-		pos_=str_buf.find("network-game-black");
-		if(pos_ != std::string::npos){
-			//start network game with black player
-			parent.on_network_game("lerosua","enemy",false);
-		}
-		pos_ = str_buf.find("network-game-win");
-		if(pos_ !=std::string::npos){
-			// i win the game.
-			if(timer.connected())
-				timer.disconnect();
-			parent.on_end_game(ROBOT_LOSE);
-			return true;
-		}
-		pos_ = str_buf.find("resign");
-		if(pos_ != std::string::npos){
-
-			if(timer.connected())
-				timer.disconnect();
-			parent.on_end_game(ROBOT_LOSE);
-			return true;
-		}
-		size_t pos=str_buf.find("moves:");
-		if(pos != std::string::npos){
-			std::string t_mv=str_buf.substr(pos+6,4);
-			std::cout<<"get robot mv = "<<t_mv<<std::endl;
-			int mv = m_engine.iccs_str_to_move(t_mv);
-			try_move(mv);
-		}
-
-		if(0 == strncmp("[{game:gmchess,",buf,15)){
-			printf("get cmd %s\n",buf);
-			string cmd=string(buf);
-			network_package* net_pac = parse_network_package(cmd);
-
-			if(net_pac->action=="ask"){
-				//对方请求的包
-				if(net_pac->status == "start"){
-					//对方请求游戏
-
-				}
-
-
-			}else if(net_pac->action == "reply"){
-				//对方回复的包
-
-
-			}else if(net_pac->action == "working"){
-				//对方走棋的包
-
-				int mv = m_engine.iccs_str_to_move(net_pac->moves);
-				try_move(mv);
-
-			}
-
-
-
-		}
-#endif
 	}
 	close(fd_cli);
 	return true;
@@ -1349,11 +1398,10 @@ bool Board::on_network_io(const Glib::IOCondition& )
 int Board::init_send_socket()
 {
 	int sockfd;
-	char buf[1024];
 	struct sockaddr_in srvaddr;
 
 	EC_THROW(-1 == (sockfd=socket(AF_INET,SOCK_STREAM,0)));
-	bzero(&srvaddr,sizeof(srvaddr));
+	memset(&srvaddr,0,sizeof(srvaddr));
 	srvaddr.sin_family=AF_INET;
 	srvaddr.sin_port=htons(GMPORT+1);
 	srvaddr.sin_addr.s_addr=htonl(INADDR_ANY);
@@ -1367,11 +1415,10 @@ void Board::send_to_socket(const std::string& cmd_)
 {
 
 	int sockfd;
-	char buf[1024];
 	struct sockaddr_in srvaddr;
 
 	EC_THROW(-1 == (sockfd=socket(AF_INET,SOCK_STREAM,0)));
-	bzero(&srvaddr,sizeof(srvaddr));
+	memset(&srvaddr,0,sizeof(srvaddr));
 	srvaddr.sin_family=AF_INET;
 	srvaddr.sin_port=htons(GMPORT+1);
 	srvaddr.sin_addr.s_addr=htonl(INADDR_ANY);
@@ -1391,3 +1438,12 @@ void Board::close_send_socket()
 		fd_send_skt=-1;
 	}
 }
+
+void Board::save_board_to_file(const std::string& filename)
+{
+	int w,h;
+	ui_pixmap->get_size(w, h);
+	Glib::RefPtr<Gdk::Pixbuf> png = Gdk::Pixbuf::create((Glib::RefPtr<Gdk::Drawable>) ui_pixmap, 0, 0,	w, h);
+	png->save(filename, "png");
+
+}
