@@ -45,6 +45,11 @@ ConfWindow::ConfWindow(MainWindow * parent_):parent(parent_)
 	bt = 0;
 	vbox_xml->get_widget("button_cancel", bt);
 	bt->signal_clicked().connect(sigc::mem_fun(*this,&ConfWindow::on_button_cancel));
+	vbox_xml->get_widget("colorbutton",colorBt);
+	colorBt->signal_color_set().connect(sigc::mem_fun(*this, &ConfWindow::on_button_color_set));
+
+	m_line_color = GMConf["line_color"];
+	colorBt->set_color(Gdk::Color(m_line_color));
 
 
 	std::string& size_big = GMConf["desktop_size"];
@@ -52,9 +57,12 @@ ConfWindow::ConfWindow(MainWindow * parent_):parent(parent_)
 	std::string& use_book = GMConf["usebook"];
 	m_usebook = (!use_book.empty()) && (use_book[0] == '1'); 
 	m_depth = GMConf["engine_depth"] ;
-	m_step_time = GMConf["step_time"] ;
-	m_play_time = GMConf["play_time"] ;
+	if(!GMConf["step_time"].empty())
+		m_step_time = GMConf["step_time"] ;
+	if(!GMConf["play_time"].empty())
+		m_play_time = GMConf["play_time"] ;
 	m_theme = GMConf["themes"];
+	m_engine_name = GMConf["engine_name"];
 
 	Gtk::HBox* hbox = 0;
 	vbox_xml->get_widget("hbox_theme", hbox);
@@ -73,6 +81,7 @@ ConfWindow::ConfWindow(MainWindow * parent_):parent(parent_)
 	m_pVariablesMap->connect_widget("sb_depth",m_depth);
 	m_pVariablesMap->connect_widget("entry_step_time",m_step_time);
 	m_pVariablesMap->connect_widget("entry_play_time",m_play_time);
+	m_pVariablesMap->connect_widget("entry_engine_name", m_engine_name);
 
 	m_pVariablesMap->transfer_variables_to_widgets();
 
@@ -97,10 +106,14 @@ void ConfWindow::on_button_save()
 
 void ConfWindow::on_button_cancel()
 {
-	//delete this;
 	parent->on_conf_window_close();
 }
+void ConfWindow::on_button_color_set()
+{
+	Gdk::Color _color = colorBt->get_color();
+	m_line_color = _color.to_string();
 
+}
 bool ConfWindow::on_delete_event(GdkEventAny*)
 {
 	on_button_cancel();
@@ -114,6 +127,8 @@ void ConfWindow::write_to_GMConf()
 	GMConf["engine_depth"] = m_depth;
 	GMConf["step_time"] = m_step_time;
 	GMConf["play_time"] = m_play_time;
+	GMConf["engine_name"] = m_engine_name;
+	GMConf["line_color"] = m_line_color;
 
 	if(cbtheme->get_active_text() == "wood")
 		GMConf["themes"] = "wood";
