@@ -22,6 +22,9 @@
 Engine::Engine():black_player(0)
 		 ,m_checked(0)
 {
+	memset(chessboard, 0 , sizeof(chessboard));
+	memset(revchessboard, 0, sizeof(revchessboard));
+	memset(chessmans, 0, sizeof(chessmans));
 	clean_board();
 }
 
@@ -211,15 +214,6 @@ void Engine::init_snapshot(const char* fen)
 	move_snapshots.push_back(0);
 
 	sync_board();
-	/*
-	int i,j;
-	for(i=0;i<16;i++)
-	{
-		for(j=0;j<16;j++)
-			printf(" %2d ",chessboard[i*16+j]);
-		printf("\n");
-	}
-	*/
 }
 
 void Engine::get_snapshot(int num)
@@ -228,6 +222,7 @@ void Engine::get_snapshot(int num)
 	//DLOG("get_snapshot = %s\n",fens.c_str());
 	clean_board();
 	from_fens(fens.c_str());
+	current_fen_snapshots = fens;
 
 	sync_board();
 
@@ -449,33 +444,41 @@ int Engine::get_knight_leg(int f_src, int f_dst)
 }
 
 /** 
+ * @brief Check if the player could mitigate checkmate status
  * 目前所有棋子的着法，检测走后是否能解除将军状态，如果都不行，则死棋
  * 死棋检测耗资源巨大，最好设定一个将军标识，在被将军状态下再检测
  * 这是在将军前提下检测死棋，没子走的情况暂不检测,公头被困死应该只剩下一个
  * 公的状态下，这种状态另外搞吧，应该很简单。
+ *
+ * 如果被将死，返回 false。
  */
 bool Engine::mate()
 {
-	/** 没被将军，那就没事，有棋,bug是将/帅被困死 */
-	m_checked = checked_by();
-	if(!m_checked)
-		return false;
-	/** 
-	 * 轮到黑方走，则生成黑方所有的着法，并一一检测，如果都不能通过，
-	 * 则死棋,如果遇到一个能通过的，则马上返回false吧
-	 */
-	DLOG("mate function\n");
-		int src;
-		int i;
-		int dst;
-		for (i = KING_FROM; i <= PAWN_TO; i++) {
-			if(src = chessmans[side_tag(black_player)+i]){
-				int chess_t =get_chessman_type(get_piece(src));
-				switch(chess_t){
-				case RED_KING:
-				case BLACK_KING:
-					for(int k=0;k<4;k++){
-						dst=src+KingMoveTab[k];
+    /** 没被将军，那就没事，有棋,bug是将/帅被困死 */
+    /** FIXME: 实现将帅被困死的情况，目前存在 bug */
+    m_checked = checked_by();
+    if(!m_checked) {
+        return false;
+    }
+
+    /**
+     * 轮到黑方走，则生成黑方所有的着法，并一一检测，如果都不能通过，
+     * 则死棋,如果遇到一个能通过的，则马上返回false吧
+     */
+    DLOG("Checkmate evaluation started\n");
+    int src;
+    int i;
+    int dst;
+
+    for (i = KING_FROM; i <= PAWN_TO; i++) {
+        src = chessmans[side_tag(black_player) + i];
+        if (src) {
+            int chess_t =  get_chessman_type(get_piece(src));
+            switch (chess_t) {
+                case RED_KING:
+                case BLACK_KING:
+                    for (int k = 0; k < 4; k++) {
+                        dst = src + KingMoveTab[k];
 						if(in_fort(dst)){
 							int mv = get_move(src,dst);
 							if(make_move(mv)){
@@ -514,7 +517,7 @@ bool Engine::mate()
 				case RED_KNIGHT:
 				case BLACK_KNIGHT:
 					for(int k=0;k<8;k++){
-						dst=src+ KingMoveTab[k];
+						dst=src+ KnightMoveTab[k];
 						if(in_board(dst)){
 							int mv = get_move(src,dst);
 							if(make_move(mv)){
@@ -643,10 +646,12 @@ bool Engine::logic_move(int mv)
 	if(!in_board(dst))
 		return false;
 	/** 检测是否同为红方的笨办法 */
-	if((chessboard[src]&16) && (chessboard[eated]&16))
+	//if((chessboard[src]&16) && (chessboard[eated]&16))
+	if((chessboard[src]&16) && (chessboard[dst]&16))
 			return false;
 	/** 检测是否同为黑方的笨办法 */
-	if((chessboard[src]&32) && (chessboard[eated]&32))
+	//if((chessboard[src]&32) && (chessboard[eated]&32))
+	if((chessboard[src]&32) && (chessboard[dst]&32))
 			return false;
 
 	/** 判断是否过河的方法，dst & 0x80,在下方是非0, 上方是0 */
@@ -759,7 +764,7 @@ bool Engine::logic_move(int mv)
 				int min_t = src<dst?src:dst;
 				int num_t = abs(RANK_Y(src)-RANK_Y(dst))-1;
 				min_t +=16;
-				int paotai=0;
+				//int paotai=0;
 				if(!eated){
 					for(int i =0;i<num_t;i++){
 						if(chessboard[min_t]==0)
@@ -770,6 +775,7 @@ bool Engine::logic_move(int mv)
 					return true;
 				}
 				else{
+					int paotai=0;
 					for(int i =0;i<num_t;i++){
 						if(chessboard[min_t]==0)
 							;
@@ -786,7 +792,6 @@ bool Engine::logic_move(int mv)
 				int min_t = src<dst?src:dst;
 				int num_t = abs(src-dst) -1 ;
 				min_t++;
-				int paotai=0;
 				if(!eated){
 					for(int i =0;i<num_t; i++){
 						if(chessboard[min_t]==0)
@@ -797,6 +802,7 @@ bool Engine::logic_move(int mv)
 					return true;
 				}
 				else {
+					int paotai=0;
 					for(int i =0;i<num_t; i++){
 						if(chessboard[min_t]==0)
 							;
@@ -930,6 +936,7 @@ int Engine::do_move(int mv)
 	char str_fen[128];
 	to_fens(str_fen);
 	fen_snapshots.push_back(std::string(str_fen));
+	current_fen_snapshots = std::string(str_fen);
 
 	add_move_chinese(mv_line);
 
@@ -1650,7 +1657,11 @@ uint32_t Engine::hanzi_to_iccs(uint32_t f_hanzi)
 	DLOG("hazi[0...3] = %c%c%c%c\n",c_hanzi.word[0],c_hanzi.word[1],c_hanzi.word[2],c_hanzi.word[3]);
 	/** cman_type 是棋子类型*/
 	int cman_type = fen_to_piece(c_hanzi.word[0]);
-	int src_x,src_y,dst_x,dst_y;
+	//int src_x,src_y,dst_x,dst_y;
+	int src_x = 0;
+	int src_y = 0;
+	int dst_x = 0;
+	int dst_y = 0;
 	int num =0;
 
 	DLOG("who is going black=%d\n",black_player);
@@ -1935,7 +1946,7 @@ uint32_t Engine::hanzi_to_iccs(uint32_t f_hanzi)
 	}
 	else if(4==cman_type||5==cman_type){
 		/** 车炮的目标坐标生成*/
-		int type_num;
+		int type_num=0;
 			if(cman_type==4)
 				type_num = 23;
 			else if(5==cman_type)
@@ -2095,7 +2106,7 @@ uint32_t Engine::hanzi_to_iccs(uint32_t f_hanzi)
 							n++;
 						}
 					}
-					DLOG(" n=%d\n");
+					DLOG(" n=%d\n", n);
 					/** 为纵线上的棋子排序*/
 					for(int k=start;k<n-1;k++)
 						for(int j=n-2;j>=k;j--){
@@ -2164,7 +2175,7 @@ uint32_t Engine::hanzi_to_iccs(uint32_t f_hanzi)
 		}
 
 		if(c_hanzi.word[2] == '+'){
-			char c= c_hanzi.word[3];
+			//char c= c_hanzi.word[3];
 			dst_x = src_x;
 			if(!black_player)
 				dst_y = src_y + 1;
@@ -2172,7 +2183,7 @@ uint32_t Engine::hanzi_to_iccs(uint32_t f_hanzi)
 				dst_y = src_y - 1;
 		}
 		else if(c_hanzi.word[2] == '-'){
-			char c= c_hanzi.word[3];
+			//char c= c_hanzi.word[3];
 			dst_x = src_x;
 			if(!black_player)
 				dst_y = src_y - 1;
@@ -2207,3 +2218,138 @@ void Engine::sync_board()
 	revchessboard[255]=0;
 }
 
+void Engine::gen_which_can_move(std::vector<Gdk::Point>& points, int chess_, bool rev)
+{
+	int sx,sy;
+	get_xy_from_chess(chess_,sx,sy,rev);
+	int chess_t = get_chessman_type(chess_);
+	int src = get_chessman_xy(chess_);
+	switch(chess_t){
+		/** 将/帅的着法，同一纵线或横线，移动只一个单位，在九宫内*/
+		case RED_PAWN:
+		case BLACK_PAWN:
+		case RED_KING:
+		case BLACK_KING:
+			{
+				//计算合法的能走的点再加入potins中
+			int dst = get_dst_xy(sx+1,sy, rev);
+			int mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx+1, sy));
+			dst = get_dst_xy(sx-1,sy, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx-1, sy));
+			dst = get_dst_xy(sx,sy+1, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx, sy+1));
+			dst = get_dst_xy(sx,sy-1, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx, sy-1));
+			}
+			break;
+		case RED_ADVISOR:
+		case BLACK_ADVISOR:
+			{
+				int dst = get_dst_xy(sx+1,sy+1, rev);
+				int mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx+1, sy+1));
+				dst = get_dst_xy(sx+1,sy-1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx+1, sy-1));
+				dst = get_dst_xy(sx-1,sy-1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx-1, sy-1));
+				dst = get_dst_xy(sx-1,sy+1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx-1, sy+1));
+			}
+			break;
+		case RED_BISHOP:
+		case BLACK_BISHOP:
+			{
+				int dst = get_dst_xy(sx+2,sy+2,rev);
+				int mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy+2));
+				dst = get_dst_xy(sx+2, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy-2));
+				dst = get_dst_xy(sx-2, sy+2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy+2));
+				dst = get_dst_xy(sx-2, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy-2));
+			}
+			break;
+		case RED_KNIGHT:
+		case BLACK_KNIGHT:
+			{
+				int dst = get_dst_xy(sx+1,sy+2,rev);
+				int mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+1,sy+2));
+				dst = get_dst_xy(sx+1, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+1,sy-2));
+				dst = get_dst_xy(sx-1, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-1,sy-2));
+				dst = get_dst_xy(sx-1, sy+2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-1,sy+2));
+				dst = get_dst_xy(sx-2, sy+1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy+1));
+				dst = get_dst_xy(sx-2, sy-1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy-1));
+				dst = get_dst_xy(sx+2, sy+1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy+1));
+				dst = get_dst_xy(sx+2, sy-1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy-1));
+			}
+			break;
+		case RED_ROOK:
+		case BLACK_ROOK:
+		case RED_CANNON:
+		case BLACK_CANNON:
+			{
+				for(int i = -9; i<9; ++i){
+					int dst = get_dst_xy(sx,sy+i);
+					int mv = get_move(src,dst);
+					if(logic_move(mv))
+						points.push_back(Gdk::Point(sx,sy+i));
+					dst = get_dst_xy(sx+i, sy);
+					mv = get_move(src,dst);
+					if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+i,sy));
+				}
+
+			}
+			break;
+
+	}
+
+
+
+}
