@@ -28,7 +28,11 @@
 #include "gmchess.h"
 #include "Sound.h"
 
-#define version "0.29.3"
+#ifndef VERSION
+#define version "0.29.6.3"
+#else
+#define version VERSION
+#endif
 
 Glib::ustring ui_info =
 "<ui>"
@@ -36,6 +40,7 @@ Glib::ustring ui_info =
 "		<menu action='FileMenu'>"
 "			<menuitem action='OpenFile'/>"
 "			<menuitem action='SaveAs'/>"
+"			<menuitem action='SaveBoard'/>"
 "			<separator/>"
 "			<menuitem action='FileQuit'/>"
 "        	</menu>"
@@ -77,6 +82,7 @@ MainWindow::MainWindow():menubar(NULL)
 	ui_xml->get_widget("button_end",btn_end);
 	ui_xml->get_widget("button_prev",btn_prev);
 	ui_xml->get_widget("button_next",btn_next);
+	ui_xml->get_widget("button_chanju", btn_chanjue);
 	ui_xml->get_widget("button_begin",btn_begin);
 	ui_xml->get_widget("button_lose",btn_lose);
 	ui_xml->get_widget("button_draw",btn_draw);
@@ -99,12 +105,14 @@ MainWindow::MainWindow():menubar(NULL)
 			sigc::mem_fun(*this, &MainWindow::on_draw_game));
 	btn_rue->signal_clicked().connect(
 			sigc::mem_fun(*this, &MainWindow::on_rue_game));
+	btn_chanjue->signal_clicked().connect(
+			sigc::mem_fun(*this, &MainWindow::on_chanju_game));
 
 	board = Gtk::manage(new Board(*this));
 	box_board->pack_start(*board);
 
 	this->add(*main_window);
-	this->set_title("GMChess");
+	this->set_title(_("GMChess"));
 
 	ui_logo  = Gdk::Pixbuf::create_from_file(DATA_DIR"/gmchess.png");
 	this->set_icon(ui_logo);
@@ -121,9 +129,9 @@ MainWindow::MainWindow():menubar(NULL)
 	m_refTreeModel = Gtk::ListStore::create(m_columns);
 	m_treeview.set_model( m_refTreeModel);
 	scrolwin->add(m_treeview);
-	m_treeview.append_column(_("bout"),m_columns.step_bout);
+	m_treeview.append_column(_("Turn"),m_columns.step_bout);
 	m_treeview.append_column("  ",m_columns.player);
-	m_treeview.append_column(_("step"),m_columns.step_line);
+	m_treeview.append_column(_("Move"),m_columns.step_line);
 	m_treeview.set_events(Gdk::BUTTON_PRESS_MASK);
 	m_treeview.signal_button_press_event().connect(sigc::mem_fun(*this,
 				&MainWindow::on_treeview_click),false);
@@ -148,9 +156,11 @@ MainWindow::MainWindow():menubar(NULL)
 	this->signal_check_resize().connect(
 			sigc::mem_fun(*this,&MainWindow::on_size_change));
 	
-	/** test for rgba */
+#ifdef __linux__
+	/** test for rgba , it not work in mac osx*/
 	Glib::RefPtr<const Gdk::Colormap> colormap_ = this->get_screen()->get_rgba_colormap();
 	this->set_default_colormap(colormap_);
+#endif
 
 	show_all();
 	p1_image->hide();
@@ -163,14 +173,28 @@ MainWindow::MainWindow():menubar(NULL)
 	int _depth = atoi(GMConf["engine_depth"].c_str());
 	g_log("Mainwindow",G_LOG_LEVEL_INFO,"depth %d",_depth);
 	board->set_level_config(_depth,0,0,0,0,0,atoi(GMConf["usebook"].c_str()));
-	int _step_time= atoi(GMConf["step_time"].c_str());
-	int _play_time= atoi(GMConf["play_time"].c_str());
+	std::string tmp = GMConf["step_time"];
+	if(tmp.empty())
+		tmp = "240";
+	//int _step_time= atoi(GMConf["step_time"].c_str());
+	int _step_time= atoi(tmp.c_str());
+	tmp = GMConf["play_time"];
+	if(tmp.empty())
+		tmp="60";
+	//int _play_time= atoi(GMConf["play_time"].c_str());
+	int _play_time= atoi(tmp.c_str());
 	if(_step_time>0&&_step_time<600 && _play_time>0)
 		board->set_time(_step_time,_play_time);
 	std::string theme_ = GMConf["themes"];
+	std::string engine_name = GMConf["engine_name"];
+	std::string color_ = GMConf["line_color"];
+	if(engine_name.empty())
+		engine_name = "eleeye_engine";
 	if(theme_.empty())
 		theme_ = "wood";
 	board->set_themes(theme_);
+	board->set_engine(engine_name);
+	board->set_trace_color(color_.c_str());
 }
 
 MainWindow::~MainWindow()
@@ -200,8 +224,8 @@ void MainWindow::change_play(bool player)
 void MainWindow::save_conf()
 {
 
-	char buf[512];
-	std::string homedir=Glib::get_user_config_dir();
+	char buf[512]; // FIXME: Do not use char buffer array
+	std::string homedir = Glib::get_user_config_dir();
 	snprintf(buf, 512,"%s/gmchess/config",homedir.c_str());
 	std::ofstream file(buf);
 	std::string line;
@@ -227,6 +251,9 @@ void MainWindow::init_conf()
 
 	std::ifstream file(buf);
 	if(!file){
+#ifdef __APPLE__
+		mkdir(homedir.c_str(),S_IRUSR|S_IWUSR|S_IXUSR);
+#endif
 		char homepath[512];
 		snprintf(homepath,512,"%s/gmchess/",homedir.c_str());
 		mkdir(homepath,S_IRUSR|S_IWUSR|S_IXUSR);
@@ -234,6 +261,8 @@ void MainWindow::init_conf()
 		GMConf["desktop_size"] = "1"; //0--small,1--big
 		GMConf["engine_depth"] ="5";
 		GMConf["themes"]="wood";
+		GMConf["engine_name"] = "eleeye_engine";
+		GMConf["line_color"] = "#198964";
 		save_conf();
 
 		snprintf(file_dir,512,"%s/gmchess/files",homedir.c_str());
@@ -377,6 +406,10 @@ void MainWindow::init_ui_manager()
 	action->set_tooltip(_("Save as a chess pgn file"));
 	action_group->add(action,
 			sigc::mem_fun(*this,&MainWindow::on_menu_save_file));
+	action = Gtk::Action::create("SaveBoard", Gtk::Stock::SAVE, _("Save Board"));
+	action->set_tooltip(_("Save board to a png file"));
+	action_group->add(action,
+			sigc::mem_fun(*this, &MainWindow::on_menu_save_board_to_png));
 
 	action_group->add(Gtk::Action::create("FileQuit", Gtk::Stock::QUIT),
 			sigc::mem_fun(*this, &MainWindow::on_menu_file_quit));
@@ -394,7 +427,7 @@ void MainWindow::init_ui_manager()
 			sigc::mem_fun(*this, &MainWindow::on_menu_war_to_ai));
 	action_group->add(Gtk::Action::create("FreePlay",Gtk::Stock::MEDIA_PLAY,_("Free Play")),
 			sigc::mem_fun(*this, &MainWindow::on_menu_free_play));
-	action_group->add(Gtk::Action::create("RevPlay",Gtk::Stock::MEDIA_PLAY,_("Change Side")),
+	action_group->add(Gtk::Action::create("RevPlay",Gtk::Stock::MEDIA_PLAY,_("_Switch colour")),
 			sigc::mem_fun(*this, &MainWindow::on_menu_rev_play));
 	//Help menu:
 	action_group->add(Gtk::Action::create("HelpMenu", _("_Help")));
@@ -412,6 +445,11 @@ void MainWindow::init_ui_manager()
 
 }
 
+void MainWindow::on_menu_save_board_to_png()
+{
+	board->save_board_to_file("/tmp/1.png");
+}
+
 void MainWindow::on_menu_save_file()
 {
 
@@ -564,76 +602,76 @@ void MainWindow:: on_menu_open_file()
 
 void MainWindow::open_file(const std::string& filename)
 {
-	if(board->is_fight_to_robot()){
-		Gtk::MessageDialog dialog(*this, _("AI Warn"), false,
-                                  Gtk::MESSAGE_QUESTION,
-                                  Gtk::BUTTONS_OK_CANCEL);
-		Glib::ustring msg =_("Open book view will close the AI game,Are you sure?");
-		dialog.set_secondary_text(msg);
-		int result = dialog.run();
-		switch (result) {
-			case (Gtk::RESPONSE_OK): {
-				board->free_game();
-                	        break;
-                	}
+    if (board->is_fight_to_robot()) {
+        Gtk::MessageDialog dialog(*this, _("AI Warn"), false,
+                Gtk::MESSAGE_QUESTION,
+                Gtk::BUTTONS_OK_CANCEL);
+        Glib::ustring msg =_("Open book view will close the AI game. Are you sure?");
+        dialog.set_secondary_text(msg);
 
-			case (Gtk::RESPONSE_CANCEL): {
-				return;
-                	        break;
-                	}
+        int result = dialog.run();
+        switch (result) {
+            case (Gtk::RESPONSE_OK): {
+                board->free_game();
+                break;
+            } 
+            case (Gtk::RESPONSE_CANCEL): {
+                return;
+                break;
+            }
+            default: {
+                return;
+                break;
+            }
+        } /* switch */
+    } /* if */
 
-			default: {
-				return;
-                	        break;
-                	}
-		}
-	}
+    /** 获取文件后先它将它转换成pgn文件才能打开*/
+    /** get the file, convert it to pgn file */
+    int out;
+    std::string::size_type const pos = filename.find(".pgn");
 
-	/** 获取文件后先它将它转换成pgn文件才能打开*/
-	/** get the file,and convert it to pgn file */
-		int out;
-
-		size_t pos = filename.find(".pgn");
-		if(pos == std::string::npos){
-			char cmd[1024];
-			sprintf(cmd,"convert_pgn \"%s\" ",filename.c_str());
-			if(system(cmd)<0){
-				DLOG("convert pgn file error\n");
-				return;
-			}
-
-			out = board->open_file("/tmp/gmchess.pgn");
-		}
-		else
-			out = board->open_file( filename);
-		if(out<0){
-			DLOG("open file: %s error\n",filename.c_str());
-			Gtk::MessageDialog dialog("Error",false,
-					Gtk::MESSAGE_INFO);
-			dialog.set_secondary_text(_("the file maybe not right format for chess"));
-			dialog.run();
-		}
-		else{
-			init_move_treeview();
-			set_information();
-			m_notebook->set_current_page(0);
-		}
+    if (pos == std::string::npos) {
+        /* Not a pgn file, we should convert it */
+        std::string const convert_cmdline = \
+                "convert_pgn \"" + \
+                filename + \
+                "\"";
+        if (system(convert_cmdline.c_str()) < 0) {
+            DLOG("convert pgn file error\n");
+            return; // XXX: study this
+        }
 
+        out = board->open_file("/tmp/gmchess.pgn");
+    } else {
+        out = board->open_file( filename);
+    }
 
+    if (out < 0) {
+        DLOG("open file: %s error\n",filename.c_str());
+        Gtk::MessageDialog dialog("Error", false, Gtk::MESSAGE_INFO);
+        dialog.set_secondary_text(_("the file maybe not right format for chess"));
+        dialog.run();
+    } else {
+        init_move_treeview();
+        set_information();
+        m_notebook->set_current_page(0);
+    }
 }
 
+
 void MainWindow::info_window(const std::string& info)
 {
-			Gtk::MessageDialog dialog("Info",false,
-					Gtk::MESSAGE_INFO);
-			dialog.set_secondary_text(info);
-			dialog.run();
+    Gtk::MessageDialog dialog("Info",false,
+            Gtk::MESSAGE_INFO);
+    dialog.set_secondary_text(info);
+    dialog.run();
 }
 
 
 void MainWindow::on_menu_war_to_ai()
 {
-	on_begin_game();
+    on_begin_game();
 }
 
 void MainWindow::on_menu_free_play()
@@ -717,8 +755,8 @@ void MainWindow::on_conf_window_close()
 }
 void MainWindow::on_menu_help()
 {
-	printf("not realize yet\n");
-
+    Gtk::MessageDialog dialog(*this, _("Function not implemented yet"));
+    dialog.run();
 }
 
 
@@ -734,11 +772,11 @@ void MainWindow::on_menu_about()
 		if(GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>=12)
 			about->set_program_name("GMChess");
 		about->set_version(version);
-		about->set_website("http://lerosua.org");
-		about->set_copyright("Copyright (c) 2009 lerosua");
-		about->set_comments(_("GMChess is chinese chess game write by gtkmm"));
+		about->set_website("https://lerosua.github.io");
+		about->set_copyright("Copyright (c) 2009 - 2011 lerosua");
+		about->set_comments(_("GMChess is a Chinese chess game written in gtkmm."));
 		about->set_authors(authors);
-		about->set_license (_("This program is licenced under GNU General Public Licence (GPL) version 2."));
+		about->set_license (_("This program is licensed under GNU General Public Licence (GPL) version 2."));
 		Glib::ustring transer = "zh_CN lerosua@gmail.com\nru Sadovnikov Dmitry <xbadcode@mail.ru>";
 		about->set_translator_credits(transer);
 
@@ -804,7 +842,7 @@ bool MainWindow::on_treeview_click(GdkEventButton* ev)
 	if(!m_treeview.get_path_at_pos((int) ev->x, (int) ev->y, path, tvc, cx, cy))
 		return false;;
 
-	if(ev->type == GDK_2BUTTON_PRESS){
+	if(ev->type == GDK_2BUTTON_PRESS){ // TODO: alias to GDK_DOUBLE_BUTTON_PRESS
 		int num = (*iter)[m_columns.step_num];
 		board->get_board_by_move(num);
 
@@ -818,8 +856,6 @@ bool MainWindow::on_treeview_click(GdkEventButton* ev)
 
 void MainWindow::set_information()
 {
-	//Gtk::Label* p1_name= 0;ui_xml->get_widget("P1_name",p1_name);
-	//Gtk::Label* p2_name= 0;ui_xml->get_widget("P2_name",p2_name);
 	Gtk::Label* info   = 0;ui_xml->get_widget("info_label",info);
 	
 	const Board_info& board_info = board->get_board_info();
@@ -884,7 +920,7 @@ void MainWindow::set_status()
 
 }
 
-void MainWindow::on_network_game(const std::string me_name,const std::string& enemy_name,bool role_red_)
+void MainWindow::on_network_game(const std::string& me_name,const std::string& enemy_name,bool role_red_)
 {
 		p1_name->set_text(enemy_name);
 		p2_name->set_text(me_name);
@@ -898,6 +934,53 @@ void MainWindow::on_network_game(const std::string me_name,const std::string& en
 	btn_begin->set_sensitive(false);
 		
 	
+}
+
+void MainWindow::on_chanju_game()
+{
+	/** 已经在对战中，则询问是否开始新游戏*/
+	/** ask if start new game */
+	if(board->is_fight_to_robot()){
+
+		Gtk::MessageDialog dialog(*this, _("new game"), false,
+                                  Gtk::MESSAGE_QUESTION,
+                                  Gtk::BUTTONS_OK_CANCEL);
+		Glib::ustring msg =_("Will you start a new game?");
+		dialog.set_secondary_text(msg);
+		int result = dialog.run();
+		switch (result) {
+			case (Gtk::RESPONSE_OK): {
+				m_refTreeModel->clear();
+				board->chanju_game();
+                	        break;
+                	}
+
+			case (Gtk::RESPONSE_CANCEL): {
+                	        break;
+                	}
+
+			default: {
+                	        break;
+                	}
+		}
+		return;
+
+	}
+	else if(board->is_network_game()){
+		Gtk::MessageDialog dialog_info(*this, _("Information"), false);
+		Glib::ustring msg =_("You are play online, Please end this game first!");
+		dialog_info.set_secondary_text(msg);
+		dialog_info.run();
+		return ;
+
+	}
+	m_refTreeModel->clear();
+	board->start_robot(false);
+	set_status();
+	btn_begin->set_sensitive(false);
+	//btn_chanjue->set_sensitive(false);
+
+
 }
 
 void MainWindow::on_begin_game()
@@ -909,7 +992,7 @@ void MainWindow::on_begin_game()
 		Gtk::MessageDialog dialog(*this, _("new game"), false,
                                   Gtk::MESSAGE_QUESTION,
                                   Gtk::BUTTONS_OK_CANCEL);
-		Glib::ustring msg =_("Will you  start a new game?");
+		Glib::ustring msg =_("Will you start a new game?");
 		dialog.set_secondary_text(msg);
 		int result = dialog.run();
 		switch (result) {
@@ -932,9 +1015,9 @@ void MainWindow::on_begin_game()
 	}
 	else if(board->is_network_game()){
 		Gtk::MessageDialog dialog_info(*this, _("Information"), false);
-		Glib::ustring msg =_("You are play with network game,Please over it first!");
+		Glib::ustring msg =_("You are playing online, Please end this game first!");
 		dialog_info.set_secondary_text(msg);
-		int result = dialog_info.run();
+		dialog_info.run();
 		return ;
 
 	}
@@ -984,15 +1067,15 @@ void MainWindow::on_lose_game()
         int result =dialog.run();
         switch (result) {
             case (Gtk::RESPONSE_OK): {
-		    board->send_to_socket("resign");
-		Gtk::MessageDialog dialog_info(*this, _("Information"), false);
-		Glib::ustring msg =_("You lose the game!");
-		dialog_info.set_secondary_text(msg);
-		int result = dialog_info.run();
-                board->free_game();
-                set_status();
+				board->send_to_socket("resign");
+				Gtk::MessageDialog dialog_info(*this, _("Information"), false);
+				Glib::ustring msg =_("You lose the game!");
+				dialog_info.set_secondary_text(msg);
+				dialog_info.run();
+				board->free_game();
+				set_status();
                             break;
-                    }
+				}
 
             case (Gtk::RESPONSE_CANCEL): {
                 //board->free_game(false);
@@ -1018,9 +1101,9 @@ void MainWindow::on_draw_game()
 			board->send_to_socket("draw");
 		}else{
 			Gtk::MessageDialog dialog(*this, _("Warning"), false);
-			Glib::ustring msg =_("Only ask rue game when you are going,so wait a minute!");
+			Glib::ustring msg =_("You may only take a back move when it's your turn. Please wait a minute!");
 			dialog.set_secondary_text(msg);
-			int result = dialog.run();
+			dialog.run();
 		}
 	}
 
@@ -1038,9 +1121,9 @@ void MainWindow::on_rue_game()
 			board->rue_move();
 		}else{
 			Gtk::MessageDialog dialog(*this, _("Warning"), false);
-			Glib::ustring msg =_("Only rue game when you are going,so wait a minute!");
+			Glib::ustring msg =_("You can only take a back move when it's your turn. Please wait a minute!");
 			dialog.set_secondary_text(msg);
-			int result = dialog.run();
+			dialog.run();
 		}
 
 	}
@@ -1050,9 +1133,9 @@ void MainWindow::on_rue_game()
 			board->send_to_socket("rue");
 		}else{
 			Gtk::MessageDialog dialog(*this, _("Warning"), false);
-			Glib::ustring msg =_("Only rue game when you are going,so wait a minute!");
+			Glib::ustring msg =_("You can only take a back move when it's your turn. Please wait a minute!");
 			dialog.set_secondary_text(msg);
-			int result = dialog.run();
+			dialog.run();
 		}
 
 
@@ -1065,12 +1148,12 @@ bool MainWindow::on_end_game(OVERSTATUS _over)
 	switch(_over){
 		case ROBOT_WIN:
 			//robot win
-			msg=_("You are Lose! \n Are you want to start a new game?");
+			msg=_("You Lose!\nDo you want to start a new game?");
 			CSound::play(SND_LOSS);
 			break;
 		case ROBOT_LOSE:
 			//robot lose
-			msg=_("Congratuations ! YOU WIN!\n start a new game click OK");
+			msg=_("Congratuations, YOU WIN!\nTo start a new game, click OK");
 			CSound::play(SND_WIN);
 			break;
 		case ROBOT_DRAW:
@@ -1079,19 +1162,19 @@ bool MainWindow::on_end_game(OVERSTATUS _over)
 			break;
 		case ROBOT_OVER_TIME:
 			// robot overload time,lose
-			msg = _("The Enemy overload the time, You Win!");
+			msg = _("The opponent used up their time. You Win!");
 			CSound::play(SND_WIN);
 			break;
 		case HUMAN_OVER_TIME:
-			msg = _("You overload the time, You Lose!");
+			msg = _("You used up your time. You Lose!");
 			CSound::play(SND_LOSS);
 		default:
 			break;
 
 	}
-		Gtk::MessageDialog dialog_info(*this, _("Game End"), false);
+		Gtk::MessageDialog dialog_info(*this, _("Game Over"), false);
 		dialog_info.set_secondary_text(msg);
-		int result = dialog_info.run();
+		dialog_info.run();
 
 		if(board->is_network_game())
 			auto_save_chess_file();
@@ -1120,8 +1203,7 @@ void MainWindow::watch_socket(int fd)
 }
 void MainWindow::start_with(const std::string& param)
 {
-		size_t pos;
-		if((pos = param.find("network-game-red,"))!= std::string::npos){
+		if((param.find("network-game-red,"))!= std::string::npos){
 			//start network game with red player
 			std::string enemy_name,my_name;
 			size_t pos_s,pos_e,pos_m;
@@ -1133,7 +1215,7 @@ void MainWindow::start_with(const std::string& param)
 			my_name = param.substr(pos_e+9,pos_m-pos_e-9);
 			
 			on_network_game(enemy_name,my_name,true);
-		}else if((pos = param.find("network-game-black,")) != std::string::npos){
+		}else if((param.find("network-game-black,")) != std::string::npos){
 			//start network game with black player
 			std::string enemy_name,my_name;
 			size_t pos_s,pos_e,pos_m;
