@@ -16,18 +16,15 @@
  * =====================================================================================
  */
 
-#ifndef  MAINWINDOW_FILE_HEADER_INC
-#define  MAINWINDOW_FILE_HEADER_INC
+#ifndef  GMCHESS_MAINWINDOW_FILE_HEADER_INC
+#define  GMCHESS_MAINWINDOW_FILE_HEADER_INC
 
 #include <gtkmm.h>
 #include <gtkmm/window.h>
-//#include <libglademm/xml.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
 #include "Board.h"
 #define main_ui  DATA_DIR"/gmchess.glade"
-//typedef Glib::RefPtr < Gnome::Glade::Xml > GlademmXML;
-typedef Glib::RefPtr < Gtk::Builder> GBuilderXML;
 
 class Board;
 class BookView;
@@ -48,13 +45,15 @@ class MainWindow:public Gtk::Window
 		void on_back_move();
 		/** 开始AI对战*/
 		void on_begin_game();
+		/** start chanhue game*/
+		void on_chanju_game();
 		/** 开始网络对战*/
 		/**
 		 * @param me_ 已方名字
 		 * @param enemy_ 对方名字
 		 * @param role_red_ 已方角色
 		 */
-		void on_network_game(const std::string me_,const std::string& enemy_,bool role_red_=true);
+		void on_network_game(const std::string& me_,const std::string& enemy_,bool role_red_=true);
 		/** gmchess最开始运行带的参数解释函数*/
 		void start_with(const std::string& param);
 		/** 认输*/
@@ -100,6 +99,7 @@ class MainWindow:public Gtk::Window
 		void init_ui_manager();
 		void on_menu_open_file();
 		void on_menu_save_file();
+		void on_menu_save_board_to_png();
 		void on_menu_file_quit();
 		void on_menu_view_preferences();
 		void on_menu_war_to_ai();
@@ -134,6 +134,7 @@ class MainWindow:public Gtk::Window
 		Glib::RefPtr<Gtk::ListStore>	m_refTreeModel;
 		
 	private:
+		typedef Glib::RefPtr < Gtk::Builder> GBuilderXML;
 		Board*				board;
 		GBuilderXML			ui_xml;
 		Glib::RefPtr<Gtk::UIManager>	ui_manager;
@@ -161,12 +162,14 @@ class MainWindow:public Gtk::Window
 		Gtk::Button*			btn_end ;
 		Gtk::Button*			btn_prev;
 		Gtk::Button*			btn_next;
+		Gtk::Button*			btn_chanjue;
 		/** 对战按钮*/
 		Gtk::Button*			btn_begin;
 		Gtk::Button*			btn_lose;
 		Gtk::Button*			btn_draw;
 		Gtk::Button*			btn_rue;
+
 };
 
 
-#endif   /* ----- #ifndef MAINWINDOW_FILE_HEADER_INC  ----- */
+#endif   /* ----- #ifndef GMCHESS_MAINWINDOW_FILE_HEADER_INC  ----- */
