@@ -17,6 +17,8 @@ enum SOUND_EVENTS
 	SND_CHECK,
 	SND_MOVE,
 	SND_CHOOSE,
+	SND_WIN,
+	SND_LOSS,
 	SND_10,
 	SND_9,
 	SND_8,
