@@ -21,37 +21,44 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "base.h"
-#include "x86asm.h"
+#if defined (__i386__)
+	#include "x86asm.h"
+#elif defined (__mips__)
+	#include "mips.h"
+#else
+	#include "mips.h"
+//#error "what's your plantform?"
+#endif
 #include "pregen.h"
 #include "position.h"
 
-/* ElephantEyeԴʹõǺԼ
+/* ElephantEye源程序使用的匈牙利记号约定：
  *
- * sq: (0255"pregen.cpp")
- * pc: (047"position.cpp")
- * pt: (06"position.cpp")
- * mv: ŷ(065535"position.cpp")
- * sd: ӷ(0췽1ڷ)
- * vl: ֵ("-MATE_VALUE""MATE_VALUE""position.cpp")
- * (עǺſucdwȴļǺʹ)
- * pos: (PositionStructͣ"position.h")
- * sms: λкλеŷԤýṹ("pregen.h")
- * smv: λкλеŷжԤýṹ("pregen.h")
+ * sq: 格子序号(整数，从0到255，参阅"pregen.cpp")
+ * pc: 棋子序号(整数，从0到47，参阅"position.cpp")
+ * pt: 棋子类型序号(整数，从0到6，参阅"position.cpp")
+ * mv: 着法(整数，从0到65535，参阅"position.cpp")
+ * sd: 走子方(整数，0代表红方，1代表黑方)
+ * vl: 局面价值(整数，从"-MATE_VALUE"到"MATE_VALUE"，参阅"position.cpp")
+ * (注：以上五个记号可与uc、dw等代表整数的记号配合使用)
+ * pos: 局面(PositionStruct类型，参阅"position.h")
+ * sms: 位行和位列的着法生成预置结构(参阅"pregen.h")
+ * smv: 位行和位列的着法判断预置结构(参阅"pregen.h")
  */
 
-// ģ漰"PositionStruct"ĳԱ"this->"ǳԷ
+// 本模块涉及多个"PositionStruct"的成员，用"this->"标记出来以方便辨认
 
-// ʼFEN
+// 起始局面的FEN串
 const char *const cszStartFen = "rnbakabnr/9/1c5c1/p1p1p1p1p/9/9/P1P1P1P1P/1C5C1/9/RNBAKABNR w";
 
-// ͶӦӷ
+// 棋子类型对应的棋子符号
 const char *const cszPieceBytes = "KABNRCP";
 
-/* ŶӦ
+/* 棋子序号对应的棋子类型
  *
- * ElephantEyeŴ047015ã1631ʾӣ3247ʾӡ
- * ÿ˳ǣ˧ڱ(ʿʿ)
- * ʾжǺ"pc < 32""pc >= 32"
+ * ElephantEye的棋子序号从0到47，其中0到15不用，16到31表示红子，32到47表示黑子。
+ * 每方的棋子顺序依次是：帅仕仕相相马马车车炮炮兵兵兵兵兵(将士士象象马马车车炮炮卒卒卒卒卒)
+ * 提示：判断棋子是红子用"pc < 32"，黑子用"pc >= 32"
  */
 const int cnPieceTypes[48] = {
   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -59,14 +66,14 @@ const int cnPieceTypes[48] = {
   0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6, 6, 6, 6, 6
 };
 
-// ӵļ򵥷ֵֻڼ򵥱Ƚʱο
+// 棋子的简单分值，只在简单比较时作参考
 const int cnSimpleValues[48] = {
   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
   5, 1, 1, 1, 1, 3, 3, 4, 4, 3, 3, 2, 2, 2, 2, 2,
   5, 1, 1, 1, 1, 3, 3, 4, 4, 3, 3, 2, 2, 2, 2, 2,
 };
 
-// ܷʵľ(ҶԳ)
+// 该数组很方便地实现了坐标的镜像(左右对称)
 const uint8_t cucsqMirrorTab[256] = {
   0, 0, 0,    0,    0,    0,    0,    0,    0,    0,    0,    0, 0, 0, 0, 0,
   0, 0, 0,    0,    0,    0,    0,    0,    0,    0,    0,    0, 0, 0, 0, 0,
@@ -86,7 +93,7 @@ const uint8_t cucsqMirrorTab[256] = {
   0, 0, 0,    0,    0,    0,    0,    0,    0,    0,    0,    0, 0, 0, 0, 0,
 };
 
-// FENӱʶעֻʶдĸСдĸʱȱתΪд
+// FEN串中棋子标识，注意这个函数只能识别大写字母，因此用小写字母时，首先必须转换为大写
 int FenPiece(int nArg) {
   switch (nArg) {
   case 'K':
@@ -110,9 +117,9 @@ int FenPiece(int nArg) {
   }
 }
 
-// һЩ̴
+// 以下是一些棋盘处理过程
 
-// 
+// 棋盘上增加棋子
 void PositionStruct::AddPiece(int sq, int pc, bool bDel) {
   int pt;
 
@@ -149,13 +156,13 @@ void PositionStruct::AddPiece(int sq, int pc, bool bDel) {
   this->zobr.Xor(PreGen.zobrTable[pt][sq]);
 }
 
-// ƶ
+// 移动棋子
 int PositionStruct::MovePiece(int mv) {
   int sqSrc, sqDst, pcMoved, pcCaptured, pt;
   uint8_t *lpucvl;
-  // ƶӰ¼裺
+  // 移动棋子包括以下几个步骤：
 
-  // 1. õƶźͱԵţ
+  // 1. 得到移动的棋子序号和被吃的棋子序号；
   sqSrc = SRC(mv);
   sqDst = DST(mv);
   pcMoved = this->ucpcSquares[sqSrc];
@@ -165,8 +172,8 @@ int PositionStruct::MovePiece(int mv) {
   pcCaptured = this->ucpcSquares[sqDst];
   if (pcCaptured == 0) {
 
-    // 2. ûбԵӣôĿλкλС
-    //    仰˵бԵӣĿλкλоͲظˡ
+    // 2. 如果没有被吃的棋子，那么更新目标格的位行和位列。
+    //    换句话说，有被吃的棋子，目标格的位行和位列就不必更新了。
     this->wBitRanks[RANK_Y(sqDst)] ^= PreGen.wBitRankMask[sqDst];
     this->wBitFiles[FILE_X(sqDst)] ^= PreGen.wBitFileMask[sqDst];
     __ASSERT_BITRANK(this->wBitRanks[RANK_Y(sqDst)]);
@@ -174,8 +181,8 @@ int PositionStruct::MovePiece(int mv) {
   } else {
 
     __ASSERT_PIECE(pcCaptured);
-    // 3. бԵӣôλ"ucsqPieces"
-    //    ͬʱֵλλСZobristֵУ
+    // 3. 如果有被吃的棋子，那么更新棋子位，从"ucsqPieces"数组中清除被吃棋子
+    //    同时更新子力价值、位行位列、Zobrist键值和校验锁
     this->ucsqPieces[pcCaptured] = 0;
     this->dwBitPiece ^= BIT_PIECE(pcCaptured);
     pt = PIECE_TYPE(pcCaptured);
@@ -189,8 +196,8 @@ int PositionStruct::MovePiece(int mv) {
     this->zobr.Xor(PreGen.zobrTable[pt][sqDst]);
   }
 
-  // 4. "ucpcSquares""ucsqPieces"ƶӣע⡰-ϵ顱ƶӵķ
-  //    ͬʱλСλСֵλλСZobristֵУ
+  // 4. 从"ucpcSquares"和"ucsqPieces"数组中移动棋子，注意“格子-棋子联系数组”移动棋子的方法
+  //    同时更新位行、位列、子力价值、位行位列、Zobrist键值和校验锁
   this->ucpcSquares[sqSrc] = 0;
   this->ucpcSquares[sqDst] = pcMoved;
   this->ucsqPieces[pcMoved] = sqDst;
@@ -212,7 +219,7 @@ int PositionStruct::MovePiece(int mv) {
   return pcCaptured;
 }
 
-// ƶ
+// 撤消移动棋子
 void PositionStruct::UndoMovePiece(int mv, int pcCaptured) {
   int sqSrc, sqDst, pcMoved;
   sqSrc = SRC(mv);
@@ -243,12 +250,12 @@ void PositionStruct::UndoMovePiece(int mv, int pcCaptured) {
 
 #include <stdio.h>
 
-// 
+// 升变
 int PositionStruct::Promote(int sq) {
   int pcCaptured, pcPromoted, pt;
-  // ¼裺
+  // 升变包括以下几个步骤：
 
-  // 1. õǰӵţ
+  // 1. 得到升变前棋子的序号；
   __ASSERT_SQUARE(sq);
   __ASSERT(CanPromote());
   __ASSERT(CAN_PROMOTE(sq));
@@ -258,7 +265,7 @@ int PositionStruct::Promote(int sq) {
   __ASSERT_PIECE(pcPromoted);
   __ASSERT(this->ucsqPieces[pcPromoted] == 0);
 
-  // 2. ȥǰӣͬʱֵZobristֵУ
+  // 2. 去掉升变前棋子，同时更新子力价值、Zobrist键值和校验锁
   this->dwBitPiece ^= BIT_PIECE(pcPromoted) ^ BIT_PIECE(pcCaptured);
   this->ucsqPieces[pcCaptured] = 0;
   pt = PIECE_TYPE(pcCaptured);
@@ -271,7 +278,7 @@ int PositionStruct::Promote(int sq) {
   __ASSERT_BOUND(0, pt, 13);
   this->zobr.Xor(PreGen.zobrTable[pt][sq]);
 
-  // 3. ӣͬʱֵZobristֵУ
+  // 3. 加上升变后棋子，同时更新子力价值、Zobrist键值和校验锁
   this->ucpcSquares[sq] = pcPromoted;
   this->ucsqPieces[pcPromoted] = sq;
   pt = PIECE_TYPE(pcPromoted);
@@ -286,7 +293,7 @@ int PositionStruct::Promote(int sq) {
   return pcCaptured;
 }
 
-// 
+// 撤消升变
 void PositionStruct::UndoPromote(int sq, int pcCaptured) {
   int pcPromoted;
   __ASSERT_SQUARE(sq);
@@ -299,35 +306,35 @@ void PositionStruct::UndoPromote(int sq, int pcCaptured) {
   this->dwBitPiece ^= BIT_PIECE(pcPromoted) ^ BIT_PIECE(pcCaptured);
 }
 
-// һЩ̴
+// 以上是一些棋盘处理过程
 
-// һЩŷ
+// 以下是一些着法处理过程
 
-// ִһŷ
+// 执行一个着法
 bool PositionStruct::MakeMove(int mv) {
   int sq, pcCaptured;
   uint32_t dwOldZobristKey;
   RollbackStruct *lprbs;
 
-  // ﵽŷôжΪǷŷ
+  // 如果达到最大着法数，那么判定为非法着法
   if (this->nMoveNum == MAX_MOVE_NUM) {
     return false;
   }
   __ASSERT(this->nMoveNum < MAX_MOVE_NUM);
-  // ִһŷҪ¼裺
+  // 执行一个着法要包括以下几个步骤：
 
-  // 1. ԭZobristֵ
+  // 1. 保存原来的Zobrist键值
   dwOldZobristKey = this->zobr.dwKey;
   SaveStatus();
 
-  // 2. ƶӣסԵ(еĻ)
+  // 2. 移动棋子，记住吃掉的子(如果有的话)
   sq = SRC(mv);
   if (sq == DST(mv)) {
     pcCaptured = Promote(sq);
   } else {
     pcCaptured = MovePiece(mv);
 
-    // 3. ƶ󱻽ˣôŷǷǷģŷ
+    // 3. 如果移动后被将军了，那么着法是非法的，撤消该着法
     if (CheckedBy(CHECK_LAZY) > 0) {
       UndoMovePiece(mv, pcCaptured);
       Rollback();
@@ -335,20 +342,20 @@ bool PositionStruct::MakeMove(int mv) {
     }
   }
 
-  // 4. ӷ
+  // 4. 交换走子方
   ChangeSide();
 
-  // 5. ԭZobristֵ¼ظû
+  // 5. 把原来的Zobrist键值记录到检测重复的迷你置换表中
   if (this->ucRepHash[dwOldZobristKey & REP_HASH_MASK] == 0) {
     this->ucRepHash[dwOldZobristKey & REP_HASH_MASK] = this->nMoveNum;
   }
 
-  // 6. ŷ浽ʷŷбУסԵӺͽ״̬
+  // 6. 把着法保存到历史着法列表中，并记住吃掉的子和将军状态
   lprbs = this->rbsList + this->nMoveNum;
   lprbs->mvs.wmv = mv;
   lprbs->mvs.ChkChs = CheckedBy();
 
-  // 7. úŷ(Ӧ)
+  // 7. 设置和棋着法数(将军和应将不计入)
   if (pcCaptured == 0) {
     if (lprbs->mvs.ChkChs == 0) {
       lprbs->mvs.ChkChs = -ChasedBy(mv);
@@ -369,7 +376,7 @@ bool PositionStruct::MakeMove(int mv) {
   return true;
 }
 
-// һŷ
+// 撤消一个着法
 void PositionStruct::UndoMakeMove(void) {
   int sq;
   RollbackStruct *lprbs;
@@ -391,7 +398,7 @@ void PositionStruct::UndoMakeMove(void) {
   __ASSERT(this->nMoveNum > 0);
 }
 
-// ִһ
+// 执行一个空着
 void PositionStruct::NullMove(void) {
   __ASSERT(this->nMoveNum < MAX_MOVE_NUM);
   if (this->ucRepHash[this->zobr.dwKey & REP_HASH_MASK] == 0) {
@@ -404,7 +411,7 @@ void PositionStruct::NullMove(void) {
   this->nDistance ++;
 }
 
-// һ
+// 撤消一个空着
 void PositionStruct::UndoNullMove(void) {
   this->nMoveNum --;
   this->nDistance --;
@@ -416,18 +423,18 @@ void PositionStruct::UndoNullMove(void) {
   __ASSERT(this->nMoveNum > 0);
 }
 
-// һЩŷ
+// 以上是一些着法处理过程
 
-// һЩ洦
+// 以下是一些局面处理过程
 
-// FENʶ
+// FEN串识别
 void PositionStruct::FromFen(const char *szFen) {
   int i, j, k;
   int pcWhite[7];
   int pcBlack[7];
   const char *lpFen;
-  // FENʶ¼裺
-  // 1. ʼ
+  // FEN串的识别包括以下几个步骤：
+  // 1. 初始化，清空棋盘
   pcWhite[0] = SIDE_TAG(0) + KING_FROM;
   pcWhite[1] = SIDE_TAG(0) + ADVISOR_FROM;
   pcWhite[2] = SIDE_TAG(0) + BISHOP_FROM;
@@ -438,10 +445,10 @@ void PositionStruct::FromFen(const char *szFen) {
   for (i = 0; i < 7; i ++) {
     pcBlack[i] = pcWhite[i] + 16;
   }
-  /* "pcWhite[7]""pcBlack[7]"ֱ췽ͺڷÿּռеţ
-   * "pcWhite[7]"Ϊ1631δ˧ڱ
-   * Ӧ"pcWhite[7] = {16, 17, 19, 21, 23, 25, 27}"ÿһӣ1
-   * Ӷ(ӵڶ˧ͱ)ǰҪ߽
+  /* 数组"pcWhite[7]"和"pcBlack[7]"分别代表红方和黑方每个兵种即将占有的序号，
+   * 以"pcWhite[7]"为例，由于棋子16到31依次代表“帅仕仕相相马马车车炮炮兵兵兵兵兵”，
+   * 所以最初应该是"pcWhite[7] = {16, 17, 19, 21, 23, 25, 27}"，每添加一个棋子，该项就增加1，
+   * 这种做法允许添加多余的棋子(例如添加第二个帅，就变成仕了)，但添加前要做边界检测
    */
   ClearBoard();
   lpFen = szFen;
@@ -449,7 +456,7 @@ void PositionStruct::FromFen(const char *szFen) {
     SetIrrev();
     return;
   }
-  // 2. ȡϵ
+  // 2. 读取棋盘上的棋子
   i = RANK_TOP;
   j = FILE_LEFT;
   while (*lpFen != ' ') {
@@ -460,12 +467,9 @@ void PositionStruct::FromFen(const char *szFen) {
         break;
       }
     } else if (*lpFen >= '1' && *lpFen <= '9') {
-      for (k = 0; k < (*lpFen - '0'); k ++) {
-        if (j >= FILE_RIGHT) {
-          break;
-        }
-        j ++;
-      }
+/* https://github.com/xqbase/eleeye/commit/
+ * f460861b1bff7a353d36f09f3610d4dd042d003e */
+      j += (*lpFen - '0');
     } else if (*lpFen >= 'A' && *lpFen <= 'Z') {
       if (j <= FILE_RIGHT) {
         k = FenPiece(*lpFen);
@@ -500,15 +504,15 @@ void PositionStruct::FromFen(const char *szFen) {
     }
   }
   lpFen ++;
-  // 3. ȷֵķ
+  // 3. 确定轮到哪方走
   if (this->sdPlayer == (*lpFen == 'b' ? 0 : 1)) {
     ChangeSide();
   }
-  // 4. Ѿɡ桱
+  // 4. 把局面设成“不可逆”
   SetIrrev();
 }
 
-// FEN
+// 生成FEN串
 void PositionStruct::ToFen(char *szFen) const {
   int i, j, k, pc;
   char *lpFen;
@@ -537,31 +541,31 @@ void PositionStruct::ToFen(char *szFen) const {
     *lpFen = '/';
     lpFen ++;
   }
-  *(lpFen - 1) = ' '; // һ'/'滻' '
+  *(lpFen - 1) = ' '; // 把最后一个'/'替换成' '
   *lpFen = (this->sdPlayer == 0 ? 'w' : 'b');
   lpFen ++;
   *lpFen = '\0';
 }
 
-// 澵
+// 局面镜像
 void PositionStruct::Mirror(void) {
   int i, sq, nMoveNumSave;
   uint16_t wmvList[MAX_MOVE_NUM];
   uint8_t ucsqList[32];
-  // 澵Ҫ²νУ
+  // 局面镜像需要按以下步骤依次进行：
 
-  // 1. ¼ʷŷ
+  // 1. 记录所有历史着法
   nMoveNumSave = this->nMoveNum;
   for (i = 1; i < nMoveNumSave; i ++) {
     wmvList[i] = this->rbsList[i].mvs.wmv;
   }
 
-  // 2. ŷ
+  // 2. 撤消所有着法
   for (i = 1; i < nMoveNumSave; i ++) {
     UndoMakeMove();
   }
 
-  // 3. Ӵߣλü¼"ucsqList"飻
+  // 3. 把所有棋子从棋盘上拿走，位置记录到"ucsqList"数组；
   for (i = 16; i < 48; i ++) {
     sq = this->ucsqPieces[i];
     ucsqList[i - 16] = sq;
@@ -570,7 +574,7 @@ void PositionStruct::Mirror(void) {
     }
   }
 
-  // 4. ߵӰվλ·ŵϣ
+  // 4. 把拿走的棋子按照镜像位置重新放到棋盘上；
   for (i = 16; i < 48; i ++) {
     sq = ucsqList[i - 16];
     if (sq != 0) {
@@ -578,23 +582,23 @@ void PositionStruct::Mirror(void) {
     }
   }
 
-  // 6. ԭŷ
+  // 6. 还原镜像着法
   SetIrrev();
   for (i = 1; i < nMoveNumSave; i ++) {
     MakeMove(MOVE_MIRROR(wmvList[i]));
   }
 }
 
-// һЩ洦
+// 以上是一些局面处理过程
 
-// һЩŷ
+// 以下是一些着法检测过程
 
-// ŷԼ⣬ڡɱŷļ
+// 着法合理性检测，仅用在“杀手着法”的检测中
 bool PositionStruct::LegalMove(int mv) const {
   int sqSrc, sqDst, sqPin, pcMoved, pcCaptured, x, y, nSideTag;
-  // ŷԼ¼裺
+  // 着法合理性检测包括以下几个步骤：
 
-  // 1. ҪߵǷ
+  // 1. 检查要走的子是否存在
   nSideTag = SIDE_TAG(this->sdPlayer);
   sqSrc = SRC(mv);
   sqDst = DST(mv);
@@ -606,7 +610,7 @@ bool PositionStruct::LegalMove(int mv) const {
   __ASSERT_SQUARE(sqDst);
   __ASSERT_PIECE(pcMoved);
 
-  // 2. ԵǷΪԷ(гӲûĻ)
+  // 2. 检查吃到的子是否为对方棋子(如果有吃子并且没有升变的话)
   pcCaptured = this->ucpcSquares[sqDst];
   if (sqSrc != sqDst && (pcCaptured & nSideTag) != 0) {
     return false;
@@ -614,35 +618,35 @@ bool PositionStruct::LegalMove(int mv) const {
   __ASSERT_BOUND(0, PIECE_INDEX(pcMoved), 15);
   switch (PIECE_INDEX(pcMoved)) {
 
-  // 3. ˧()(ʿ)ȿǷھŹڣٿǷǺλ
+  // 3. 如果是帅(将)或仕(士)，则先看是否在九宫内，再看是否是合理位移
   case KING_FROM:
     return IN_FORT(sqDst) && KING_SPAN(sqSrc, sqDst);
   case ADVISOR_FROM:
   case ADVISOR_TO:
     if (sqSrc == sqDst) {
-      // 䣬ڵ߲ұ()ȫʱſ
+      // 考虑升变，在底线并且兵(卒)不全时，才可升变
       return CAN_PROMOTE(sqSrc) && CanPromote();
     } else {
       return IN_FORT(sqDst) && ADVISOR_SPAN(sqSrc, sqDst);
     }
 
-  // 4. ()ȿǷӣٿǷǺλƣûб
+  // 4. 如果是相(象)，则先看是否过河，再看是否是合理位移，最后看有没有被塞象眼
   case BISHOP_FROM:
   case BISHOP_TO:
     if (sqSrc == sqDst) {
-      // 䣬ڵ߲ұ()ȫʱſ
+      // 考虑升变，在底线并且兵(卒)不全时，才可升变
       return CAN_PROMOTE(sqSrc) && CanPromote();
     } else {
       return SAME_HALF(sqSrc, sqDst) && BISHOP_SPAN(sqSrc, sqDst) && this->ucpcSquares[BISHOP_PIN(sqSrc, sqDst)] == 0;
     }
 
-  // 5. ȿǷǺλƣٿûб
+  // 5. 如果是马，则先看看是否是合理位移，再看有没有被蹩马腿
   case KNIGHT_FROM:
   case KNIGHT_TO:
     sqPin = KNIGHT_PIN(sqSrc, sqDst);
     return sqPin != sqSrc && this->ucpcSquares[sqPin] == 0;
 
-  // 6. ǳȿǺƶƶٶȡλлλеŷԤ
+  // 6. 如果是车，则先看是横向移动还是纵向移动，再读取位行或位列的着法预生成数组
   case ROOK_FROM:
   case ROOK_TO:
     x = FILE_X(sqSrc);
@@ -663,7 +667,7 @@ bool PositionStruct::LegalMove(int mv) const {
       return false;
     }
 
-  // 7. ڣжͳһ
+  // 7. 如果是炮，判断起来和车一样
   case CANNON_FROM:
   case CANNON_TO:
     x = FILE_X(sqSrc);
@@ -684,7 +688,7 @@ bool PositionStruct::LegalMove(int mv) const {
       return false;
     }
 
-  // 8. Ǳ()򰴺췽ͺڷ
+  // 8. 如果是兵(卒)，则按红方和黑方分情况讨论
   default:
     if (AWAY_HALF(sqDst, this->sdPlayer) && (sqDst == sqSrc - 1 || sqDst == sqSrc + 1)) {
       return true;
@@ -694,29 +698,29 @@ bool PositionStruct::LegalMove(int mv) const {
   }
 }
 
-// 
+// 将军检测
 int PositionStruct::CheckedBy(bool bLazy) const {
   int pcCheckedBy, i, sqSrc, sqDst, sqPin, pc, x, y, nOppSideTag;
   SlideMaskStruct *lpsmsRank, *lpsmsFile;
 
   pcCheckedBy = 0;
   nOppSideTag = OPP_SIDE_TAG(this->sdPlayer);
-  // жϰ¼ݣ
+  // 将军判断包括以下几部分内容：
 
-  // 1. ж˧()Ƿ
+  // 1. 判断帅(将)是否在棋盘上
   sqSrc = this->ucsqPieces[SIDE_TAG(this->sdPlayer)];
   if (sqSrc == 0) {
     return 0;
   }
   __ASSERT_SQUARE(sqSrc);
 
-  // 2. ˧()ڸӵλкλ
+  // 2. 获得帅(将)所在格子的位行和位列
   x = FILE_X(sqSrc);
   y = RANK_Y(sqSrc);
   lpsmsRank = RankMaskPtr(x, y);
   lpsmsFile = FileMaskPtr(x, y);
 
-  // 3. жǷ˧
+  // 3. 判断是否将帅对脸
   sqDst = this->ucsqPieces[nOppSideTag + KING_FROM];
   if (sqDst != 0) {
     __ASSERT_SQUARE(sqDst);
@@ -725,12 +729,12 @@ int PositionStruct::CheckedBy(bool bLazy) const {
     }
   }
 
-  // 4. жǷ
+  // 4. 判断是否被马将军
   for (i = KNIGHT_FROM; i <= KNIGHT_TO; i ++) {
     sqDst = this->ucsqPieces[nOppSideTag + i];
     if (sqDst != 0) {
       __ASSERT_SQUARE(sqDst);
-      sqPin = KNIGHT_PIN(sqDst, sqSrc); // ע⣬sqSrcsqDstǷģ
+      sqPin = KNIGHT_PIN(sqDst, sqSrc); // 注意，sqSrc和sqDst是反的！
       if (sqPin != sqDst && this->ucpcSquares[sqPin] == 0) {
         if (bLazy || pcCheckedBy > 0) {
           return CHECK_MULTI;
@@ -741,7 +745,7 @@ int PositionStruct::CheckedBy(bool bLazy) const {
     }
   }
 
-  // 5. жǷ񱻳˧
+  // 5. 判断是否被车将军或将帅对脸
   for (i = ROOK_FROM; i <= ROOK_TO; i ++) {
     sqDst = this->ucsqPieces[nOppSideTag + i];
     if (sqDst != 0) {
@@ -766,7 +770,7 @@ int PositionStruct::CheckedBy(bool bLazy) const {
     }
   }
 
-  // 6. жǷڽ
+  // 6. 判断是否被炮将军
   for (i = CANNON_FROM; i <= CANNON_TO; i ++) {
     sqDst = this->ucsqPieces[nOppSideTag + i];
     if (sqDst != 0) {
@@ -791,9 +795,9 @@ int PositionStruct::CheckedBy(bool bLazy) const {
     }
   }
 
-  // 7. жǷ񱻱()
+  // 7. 判断是否被兵(卒)将军
   for (sqDst = sqSrc - 1; sqDst <= sqSrc + 1; sqDst += 2) {
-    // ˧()ڱ(ElephantEye)ôԲ
+    // 如果帅(将)在边线(ElephantEye允许)，那么断言不成立
     // __ASSERT_SQUARE(sqDst);
     pc = this->ucpcSquares[sqDst];
     if ((pc & nOppSideTag) != 0 && PIECE_INDEX(pc) >= PAWN_FROM) {
@@ -815,7 +819,7 @@ int PositionStruct::CheckedBy(bool bLazy) const {
   return pcCheckedBy;
 }
 
-// жǷ񱻽
+// 判断是否被将死
 bool PositionStruct::IsMate(void) {
   int i, nGenNum;
   MoveStruct mvsGen[MAX_GEN_MOVES];
@@ -826,7 +830,7 @@ bool PositionStruct::IsMate(void) {
       return false;
     }
   }
-  // ŷɷԽԼʱ
+  // 着法生成分两部分做，这样可以节约时间
   nGenNum = GenNonCapMoves(mvsGen);
   for (i = 0; i < nGenNum; i ++) {
     if (MakeMove(mvsGen[i].wmv)) {
@@ -837,7 +841,7 @@ bool PositionStruct::IsMate(void) {
   return true;
 }
 
-// ý״̬λ
+// 设置将军状态位
 inline void SetPerpCheck(uint32_t &dwPerpCheck, int nChkChs) {
   if (nChkChs == 0) {
     dwPerpCheck = 0;
@@ -848,38 +852,38 @@ inline void SetPerpCheck(uint32_t &dwPerpCheck, int nChkChs) {
   }
 }
 
-// ظ
+// 重复局面检测
 int PositionStruct::RepStatus(int nRecur) const {
-  // "nRecur"ָظȡ1Ч(Ĭֵ)㴦ȡ3Ӧ
+  // 参数"nRecur"指重复次数，在搜索中取1以提高搜索效率(默认值)，根结点处取3以适应规则
   int sd;
   uint32_t dwPerpCheck, dwOppPerpCheck;
   const RollbackStruct *lprbs;
-  /* ظ¼裺
+  /* 重复局面检测包括以下几个步骤：
    *
-   * 1. жϼظûǷеǰ棬ûпܣòж
-   *    û"ucRepHash"ElephantEyeһɫÿִһŷʱͻûм¼µǰ"nMoveNum"
-   *    ûѾ棬Ͳظˣ"MakeMove()"
-   *    ˳ŷʱֻҪûֵǷڵǰ"nMoveNum"ո
-   *    ڵǰ"nMoveNum"˵֮ǰоռûո"position.h"е"UndoMakeMove()"
+   * 1. 首先判断检测重复的迷你置换表中是否可能有当前局面，如果没有可能，就用不着判断了
+   *    置换表"ucRepHash"是ElephantEye的一个特色，局面每执行一个着法时，就会在置换表项中记录下当前的"nMoveNum"
+   *    如果置换表项已经填有其他局面，就不必覆盖了，参阅"MakeMove()"函数
+   *    因此撤消着法时，只要查找置换表项的值是否等于当前的"nMoveNum"，如果相等则清空该项
+   *    如果不等于当前的"nMoveNum"，则说明之前还有局面占有这个置换表项，不必清空该项，参阅"position.h"中的"UndoMakeMove()"函数
    */
   if (this->ucRepHash[this->zobr.dwKey & REP_HASH_MASK] == 0) {
     return 0;
   }
 
-  // 2. ʼ
+  // 2. 初始化
   sd = OPP_SIDE(this->sdPlayer);
   dwPerpCheck = dwOppPerpCheck = 0x1ffff;
   lprbs = this->rbsList + this->nMoveNum - 1;
 
-  // 3. һŷǿŻŷͲظ
+  // 3. 检查上一个着法，如果是空着或吃子着法，就不可能有重复了
   while (lprbs->mvs.wmv != 0 && lprbs->mvs.CptDrw <= 0) {
     __ASSERT(lprbs >= this->rbsList);
 
-    // 4. ж˫ĳ򼶱0ʾ޳0xffffʾ׽0x10000ʾ
+    // 4. 判断双方的长打级别，0表示无长打，0xffff表示长捉，0x10000表示长将
     if (sd == this->sdPlayer) {
       SetPerpCheck(dwPerpCheck, lprbs->mvs.ChkChs);
 
-      // 5. Ѱظ棬ظﵽԤ򷵻ظǺ
+      // 5. 寻找重复局面，如果重复次数达到预定次数，则返回重复记号
       if (lprbs->zobr.dwLock0 == this->zobr.dwLock0 && lprbs->zobr.dwLock1 == this->zobr.dwLock1) {
         nRecur --;
         if (nRecur == 0) {
@@ -899,4 +903,4 @@ int PositionStruct::RepStatus(int nRecur) const {
   return REP_NONE;
 }
 
-// һЩŷ
+// 以上是一些着法检测过程
