@@ -18,7 +18,7 @@
 #ifndef GMROBOT_H_
 #define GMROBOT_H_
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <iostream>
 #include <gtkmm.h>
 
@@ -30,6 +30,8 @@ class Robot {
 		void pause(); 
 		void stop();
 		void start();
+		void set_engine(const std::string&  name){ engine_name = name; }
+		std::string get_engine() { return engine_name ;}
 
 		bool running() const;
 		bool pausing() const { return is_pause; }
@@ -39,12 +41,12 @@ class Robot {
 		ssize_t get_robot_log(char* buf, size_t count) 
 		{ return read(child_tem, buf, count); }
 
-		typedef sigc::signal<void> type_signal_stop;
-		type_signal_stop signal_stop()
+		typedef const sigc::signal<void> type_signal_stop;
+		type_signal_stop signal_stop() const
 		{ return signal_stop_; }
 
-		typedef sigc::signal<void> type_signal_start;
-		type_signal_start signal_start()
+		typedef const sigc::signal<void> type_signal_start;
+		type_signal_start signal_start() const
 		{ return signal_start_; }	
 	protected:
 		int my_system(char* const argv[]);
@@ -62,10 +64,11 @@ class Robot {
 		type_signal_stop  		signal_stop_;
 		type_signal_start 		signal_start_;
 		int		child_tem; 	// 主进程和子进程的连接管道的主进程则
-		int 		child_tem2; 	// 子进程端的标准输入，输出
+		int 	child_tem2; 	// 子进程端的标准输入，输出
 		int		child_pid;	/* robot's pid (internal)*/
-		bool		is_running;	
-		bool		is_pause;	
+		bool	is_running;	
+		bool	is_pause;	
+		std::string  engine_name;  //the ucci engine execute file's name
 };
 
 #endif
